import fs from "fs"
import path_lib from "path"
import { Logrotate } from "syrus4-nodejs"

export class File {
	constructor( config ) { //{ host, path }
		this.onConnect = null;
		this.onDisconnect = null;
		this.onMessage = null;
		this.path = config.host || config.path;
		try {
			// create directory if it doesn't exist
			if (!fs.existsSync(this.path)){
				fs.mkdirSync(path_lib.dirname(this.path), {recursive: true})
				// touch the file
				try {
					time = new Date()
					fs.utimesSync(this.path, time, time);
				} catch (err) {
					fs.closeSync(fs.openSync(this.path, 'w'));
				}
			}

			// Configure the file rotation
			//const name = config.host.split('/').pop();
			console.log('Rotation settings:', config, this.path);
			Logrotate.setConfiguration(config.name, config.host, config.rotate, config.size, config.compress);

		} catch (error) {
			console.error("Unable to create path ", this.path);
			throw error;
		}
	}

	get disable_welcome_message() { return true }
	get no_disconnects() { return true }
	get no_acks() { return true } 

	destroy(){
		return;
	}

	connect() {
		if (this.onConnect) this.onConnect();
	}

	disconnect() {
		if (this.onDisconnect) this.onDisconnect();
	}

	send(data, next) {
		if (!next) { next = () => { } }
		try {
			fs.appendFileSync(this.path, JSON.stringify(data) + "\n", {
				encoding: "utf8"
			});
			next()
		} catch (error) {
			console.error(error);
			next(error)
		}
	}
}
