
export class CSV {
    constructor({ name, client, onCommand, autoDequeue = false }) {
        console.log('CSV Constructor:', name, client, onCommand, autoDequeue);
        this.name = name;
        if (onCommand) this.onCommand = onCommand;
        this.autoDequeue = autoDequeue;
        this.client = client;
        this.client.connect();
        this.client.onCommand = this.onCommand;
        this.variablesCount = 0;
        this.firstLoad = true;
    }


    // Must be exposed by all the protocols that supports send to destinations
	/**
	 * default send command this is called from the main, process the event To the protocol
	 * @param {Object<any>} variables syrusjs_variables copy
	 * @param {Object<any>} opts event defintion parameters, min_duration, trigger rater,etc
	 * @param {Object<any>} fields fieldset from the event
	 * @param {string} label the label from the event
	 * @param {string} code the code from the event
	 */
    send( variables, opts, fields, label, code ) {
        //console.log('CSV Send:', variables, opts, fields, label, code);   

        // Print first header - Verify the number of variables hasn't grow
        if (this.firstLoad) {
            // Get fieldset order
            let header = `timestamp,event_label,event_code,`
            for (const field in fields) {
        
                if ( !field.includes('$') ) {
                    // Field defined by alias like VO: $counters.globals.odometer
                    for (const element in variables) {
                        if (element.includes(`${fields[field]}`)) {
                            header += `${field},`;
                            this.variablesCount += 1;
                        }
                    }

                } else {
                    // Field defined by fieldset like $io, $gnss, $net ..
                    const fieldArray = [];
                    for (const element in variables) {
                        if (element.includes(`${field}`)) {
                            header += `${element},`;
                            this.variablesCount += 1;
                        }
                    }
                }

            }

            
            this.client.send(`${header}`, (error) => {
                if (error) console.error(error);
            });

            console.log('CSV Header added:', this.variablesCount, header);
            this.firstLoad = false;
        }

        let payload = ''
        let count = 0;
        // Print values in CSV format
        for (const field in fields) {
            if ( !field.includes('$') ) {
                // Field defined by alias like VO: $counters.globals.odometer
                for (const element in variables) {
                    if (element.includes(`${fields[field]}`)) {
                        payload += `${variables[element]},`; 
                        count += 1;
                    }
                }

            } else {
                // Field defined by fieldset like $io, $gnss, $net ..
                const fieldArray = [];
                for (const element in variables) {
                    if (element.includes(`${field}`)) {
                        payload += `${variables[element]},`;
                        count += 1;
                    }

                }
            }

        }   

        //console.log('CSV Payload added:', this.variablesCount, count);

        // Failsafe for variables just created
        if (this.variablesCount != count) {
            this.firstLoad = true;
        }

        //this.push('true,true,true');
        this.client.send(`${new Date().getTime()},${label},${code},${payload}`, (error) => {
            if (error) console.error(error);
        });

    } 

}